@@ -1,5 +1,9 @@
+from pathlib import Path
+
 from scisort import scisort_keygen
 
+from scitree import scitree
+
 tree = ["data", "README.md", "scripts", "installation.R", "requirements.txt", "tests"]
 
 tree_expected = [
@@ -15,3 +19,13 @@ tree_expected = [
 def test_keygen():
 
     assert sorted(tree, key=scisort_keygen()) == tree_expected
+
+
+def test_root_tree():
+
+    scitree()
+
+
+def test_root_tree_pathlib():
+
+    assert scitree() == scitree(Path("."))
